# Set of useful tools

- dtox - rename from whatever coding to ascii, works recursively
- cpuspeed - simple cpu test to compare
- pingy - big color font ping
- zoter - lauch zotero and make backup of sqlite after
- wavescan - display wifis in terminal
- sshconf - show status of PCs from ~/.ssh/config (if they have #Label: line)

## uv astral


https://docs.astral.sh/uv/guides/package/#next-steps


```
rm dist/jusfl* ; gca && bumpversion patch &&  uv build && uv publish
```
